Changelog
=========


0.1.3 (2018-03-18)
------------------

* Fix minor unhandled exception in previous release.

0.1.2 (2018-03-18)
------------------

* Fix `Issue #5 <https://github.com/jantman/versionfinder/issues/5>`_ where ``import pip`` fails if ``requests`` has previously been imported. Also proactive fix for pip10 changes.
* Multiple test fixes

0.1.1 (2017-06-16)
------------------

* Prevent dieing with an exception if ``git`` is not installed on the system.
* Add hack to ``docs/source/conf.py`` as workaround for https://github.com/sphinx-doc/sphinx/issues/3860
* Add TravisCI testing for py36

0.1.0 (2016-12-04)
------------------

* Initial Release
